pub struct GrpcServer { /* private fields */ }Expand description
A gRPC server.
Allows serving multiple gRPC services from a single endpoint.
This type is a thin wrapper over helper types from tonic and axum, and principally is meant to provide an opaque
gRPC server implementation that operates correctly when run under supervision. As such, this type can’t be manually
served: it is only usable by adding it to a supervisor.
Supervision
The listen address is bound during initialization, so a failure to bind is raised before the supervised worker starts running, and a restart rebinds.
The server will attempt to gracefully shutdown existing connections when the parent supervisor signals shutdown. This will cause the worker to utilize the maximum allowable grace period during shutdown: it will attempt to take as long as necessary to gracefully shutdown existing connections, bounded only by the parent supervisor.
Implementations
Sourceimpl GrpcServer
impl GrpcServer
Sourcepub fn new(listen_addr: ListenAddress) -> Self
pub fn new(listen_addr: ListenAddress) -> Self
Creates an empty server with no attached services, configured to listen on the given address.
Sourcepub fn with_graceful_shutdown_timeout(self, timeout: Duration) -> Self
pub fn with_graceful_shutdown_timeout(self, timeout: Duration) -> Self
Sets the graceful shutdown timeout for this server.
During shutdown, the server will for all in-flight connections to complete before ultimately completing itself. When no timeout is specified, this will lead to the worker taking the maximum allowable time to shutdown if connections are blocked or otherwise “stuck.” Setting an explicit graceful shutdown timeout will cause the worker to bound how long it waits for in-flight connections to shutdown before forcefully completing and moving on.
Defaults to no timeout (wait as long as allowed).
Sourcepub fn add_service<S>(self, svc: S) -> Selfwhere
S: Service<Request<Body>, Error = Infallible> + NamedService + Clone + Send + Sync + 'static,
S::Response: IntoResponse,
S::Future: Send + 'static,
pub fn add_service<S>(self, svc: S) -> Selfwhere
S: Service<Request<Body>, Error = Infallible> + NamedService + Clone + Send + Sync + 'static,
S::Response: IntoResponse,
S::Future: Send + 'static,
Adds a new service to this server.